==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Ftaglines-0.2-1.4.1.tar.gz: taglines/functions.php <==
<?php


   function taglines_getquote_do(&$argv) 
   {

      global $fortuneCommand, $taglineSource, $taglinePrefix;

      include_once(SM_PATH . 'plugins/taglines/config.php');


      // autodetect taglines source - if fortune program
      // isn't available, only pull from qotd - if fortune program
      // isn't available, only pull from qotd.org
      //
      if ($taglineSource == 0)
      {
         preg_match('/(.+?)(\s|$)/', $fortuneCommand, $matches);
         if (!file_exists($matches[1]))
            $taglineSource = 1;
      }


      // random number generation...
      //
      mt_srand((double)microtime()*1000000);


      // figure out where to pull tag line from and do it...
      //
      if ($taglineSource == 1 || ($taglineSource == 0 && mt_rand(1,20) > 10))
      {
 
         // if we have access to the taglines directory,
         // check age of cache 
         //
         $quotesrc = SM_PATH . 'plugins/taglines/qotd.html';
         if (is_writable(SM_PATH . 'plugins/taglines') 
          && file_exists($quotesrc))
         {
            $filemod     = filemtime($quotesrc);
            $filemodtime = date('F j Y h:i:s A', $filemod);
            $currenttime = getdate(time());
            $currentdate = $currenttime['0'];
            $difference  = $currentdate - $filemod;

            if ($difference >= 3600) 
               unlink($quotesrc);
         }


         // get qotd from website if local copy not available
         //
         if (!file_exists($quotesrc)) 
            $qotd = 'http://www.qotd.org';
         else
            $qotd = $quotesrc;


         // get qotd
         //
         $sk = fopen($qotd, 'r');
         $retstr = '';
         while(!feof($sk))
         {
            $resp=fgets($sk,80);
            $retstr.=$resp;
         }


         // parse quote out of web page
         //
         $sString = $retstr;
         $explode = explode('quote:</b>',$sString);
         $sString = $explode[1];
         $explode = explode('<A',$sString);
         $sString = $explode[0];
         $sString = str_replace('<br>','',$sString);
         $sString = str_replace('<BR>','',$sString);
         $sString = str_replace('<i>','',$sString);
         $sString = str_replace('</i>','',$sString);
         $sString = str_replace('<I>','',$sString);
         $sString = str_replace('</I>','',$sString);
         $sString = trim($sString);


         // if we have access to the taglines directory
         // and the cache file is nonexistent, save local
         // copy of web page
         //
         if (is_writable(SM_PATH . 'plugins/taglines')
          && !file_exists($quotesrc))
         {
            if ($QOTDFILE = fopen($quotesrc, 'w'))
            {
               fwrite($QOTDFILE, $retstr);
               fclose($QOTDFILE);
            }
         }

      } 


      // get tag line from fortune program
      //
      else 
      {
         $sString = shell_exec($fortuneCommand);
         //$sString = nl2br($sString);
      }


      // put tag line into body text
      //
      $tagline = $taglinePrefix . $sString;
      $message = &$argv[1];
      if (is_array($message->entities) && sizeof($message->entities) > 0)
         $message->entities[0]->body_part = $message->entities[0]->body_part . $tagline;
      else
         $message->body_part = $message->body_part . $tagline;

   }


?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Ftaglines-0.3-1.4.1.tar.gz: taglines/functions.php <==
<?php


   function taglines_getquote_do(&$argv) 
   {

      global $fortuneCommand, $taglineSource, $taglinePrefix;

      include_once(SM_PATH . 'plugins/taglines/config.php');


      // autodetect taglines source - if fortune program
      // isn't available, only pull from qotd - if fortune program
      // isn't available, only pull from qotd.org
      //
      if ($taglineSource == 0)
      {
         preg_match('/(.+?)(\s|$)/', $fortuneCommand, $matches);
         if (!file_exists($matches[1]))
            $taglineSource = 1;
      }


      // random number generation...
      //
      mt_srand((double)microtime()*1000000);


      // figure out where to pull tag line from and do it...
      //
      if ($taglineSource == 1 || ($taglineSource == 0 && mt_rand(1,20) > 10))
      {
 
         // if we have access to the taglines directory,
         // check age of cache 
         //
         $quotesrc = SM_PATH . 'plugins/taglines/qotd.html';
         if (is_writable(SM_PATH . 'plugins/taglines') 
          && file_exists($quotesrc))
         {
            $filemod     = filemtime($quotesrc);
            $filemodtime = date('F j Y h:i:s A', $filemod);
            $currenttime = getdate(time());
            $currentdate = $currenttime['0'];
            $difference  = $currentdate - $filemod;

            if ($difference >= 3600) 
               unlink($quotesrc);
         }


         // get qotd from website if local copy not available
         //
         if (!file_exists($quotesrc)) 
            $qotd = 'http://www.qotd.org/sm';
         else
            $qotd = $quotesrc;


         // get qotd
         //
         $sk = @fopen($qotd, 'r');
         $retstr = '';
         if (isset($sk) && $sk !== FALSE)
         {
            while (!feof($sk))
            {
               $resp = fgets($sk,80);
               $retstr .= $resp;
            }
         }


         // parse quote out of web page
         //
         $sString = $retstr;
         $explode = explode('randomly selected quote:</b>',$sString);
         $sString = $explode[1];
         $explode = explode("<A HREF",$sString);
         $sString = $explode[0];
/*
   // this is how to parse it from the main web site (without the /sm on the end of the URL)
         $sString = $retstr;
         $explode = explode('quote:</b>',$sString);
         $sString = $explode[1];
         $explode = explode('<A',$sString);
         $sString = $explode[0];
*/
         $sString = str_replace('<br>','',$sString);
         $sString = str_replace('<BR>','',$sString);
         $sString = str_replace('<i>','',$sString);
         $sString = str_replace('</i>','',$sString);
         $sString = str_replace('<I>','',$sString);
         $sString = str_replace('</I>','',$sString);
         $sString = trim($sString);


         // if we have access to the taglines directory
         // and the cache file is nonexistent, save local
         // copy of web page
         //
         if (is_writable(SM_PATH . 'plugins/taglines')
          && !file_exists($quotesrc))
         {
            if ($QOTDFILE = fopen($quotesrc, 'w'))
            {
               fwrite($QOTDFILE, $retstr);
               fclose($QOTDFILE);
            }
         }

      } 


      // get tag line from fortune program
      //
      else 
      {
         $sString = shell_exec($fortuneCommand);
         //$sString = nl2br($sString);
      }


      // put tag line into body text
      //
      $tagline = $taglinePrefix . $sString;
      $message = &$argv[1];
      if (is_array($message->entities) && sizeof($message->entities) > 0)
         $message->entities[0]->body_part = $message->entities[0]->body_part . $tagline;
      else
         $message->body_part = $message->body_part . $tagline;

   }


?>
